pub struct Interner { /* private fields */ }Expand description
String interner for deduplicating identifier strings.
Thread-safe via internal locking.
Implementations
Sourceimpl Interner
impl Interner
Sourcepub fn intern(&self, s: &str) -> Name
pub fn intern(&self, s: &str) -> Name
Intern a string, returning a Name handle.
If the string has been interned before, returns the existing Name.
Sourcepub fn lookup(&self, name: Name) -> Option<SmolStr>
pub fn lookup(&self, name: Name) -> Option<SmolStr>
Look up the string for a Name.
Returns None if the Name was created by a different interner.